Slot3D<T> class

Inheritance

Constructors

Slot3D(int spatial1, int spatial2, int spatial3)
Slot3D.from(Field3D field)

Properties

availablesBackward Iterable<T>
no setterinherited
availablesForward Iterable<T>
no setterinherited
first → T?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
last → T?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spatial1 int
final
spatial2 int
final
spatial3 int
final

Methods

availablesLatest([(int, int, int)? from, (int, int, int)? to]) Iterable<T>
inherited
availablesRecent([(int, int, int)? from, (int, int, int)? to]) Iterable<T>
to prevent duplicate implementation, there is no availablesFrom or availablesTo
inherited
clear() → void
clear all flags
inherited
filterOn(FieldParent field) Iterable<T>
inherited
firstAfter((int, int, int) index) → T?
inherited
includesFrom(Iterable<T> iterable, (int, int, int) begin, [bool inclusive = true]) → void
inherited
includesTo(Iterable<T> iterable, (int, int, int) last, [bool inclusive = true]) → void
inherited
isSizeEqual(Slot3D<T> other) bool
inherited
lastBefore((int, int, int) index) → T?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pasteSub(T value, (int, int, int) begin, [(int, int, int)? limit]) → void
inherited
toString() String
A string representation of this object.
inherited
validateIndex((int, int, int) index) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator []((int, int, int) index) → T?
inherited
operator []=((int, int, int) index, T? value) → void
inherited